@@ -83,7 +83,10 @@ F21  <- function(aa,bb,cc,zz,tol=1e-8,minit,maxit,DEBUG=FALSE) {
   if ((aa==1)&&is.double(bb)) suffix <- "a1bR" else
     if ((aa==1)&&is.double(cc)) suffix <- "a1cR" else
       if (is.double(aa)) suffix <- "aR"
-  Dres <- .Call(paste("F21D",suffix,sep=""),aa,bb,cc,zz,minit,maxit,package="PearsonDS")
+  Dfun <- paste0("F21D",suffix)
+  DDfun <- paste0("F21DD",suffix)
+  QDfun <- paste0("F21QD",suffix)
+  Dres <- .Call(Dfun,aa,bb,cc,zz,minit,maxit,package="PearsonDS")
   res  <- Dres$value
   ind  <- (Dres$rel*tol)<.Machine$double.eps
   ind[is.na(ind)] <- TRUE
@@ -91,14 +94,14 @@ F21  <- function(aa,bb,cc,zz,tol=1e-8,minit,maxit,DEBUG=FALSE) {
   rtolDD <- 0; rtolQD <- 0
   if (sum(!ind)>0) rtolD <- .Machine$double.eps/min(Dres$rel[!ind]) else rtolD <- 0
   if (sum(ind)>0) {
-    DDres <- .Call(paste("F21DD",suffix,sep=""),aa,bb,cc,zz[ind],minit,maxit,package="PearsonDS")
+    DDres <- .Call(DDfun,aa,bb,cc,zz[ind],minit,maxit,package="PearsonDS")
     res[ind] <- DDres$value
     ind2 <- (DDres$rel*tol)<2.465190e-32
     ind2[is.na(ind2)] <- TRUE
     if (DEBUG) cat(sum(ind2)," summands inexact (double-double)\n")
     if (sum(!ind2)>0) rtolDD <- 2.465190e-32/min(DDres$rel[!ind2]) else rtolDD <- 0
     if (sum(ind2)>0) {
-      QDres   <- .Call(paste("F21QD",suffix,sep=""),aa,bb,cc,zz[ind[ind2]],minit,maxit,package="PearsonDS")
+      QDres   <- .Call(QDfun,aa,bb,cc,zz[ind[ind2]],minit,maxit,package="PearsonDS")
       rtolQD  <- 3.038582e-64/min(QDres$rel)
       res[ind[ind2]] <- QDres$value
     }  
@@ -131,31 +134,31 @@ function(q,m,nu,location,scale,params,lower.tail=TRUE,log.p=FALSE,tol=1e-8,...)
 
     res[ind1] <- dpearsonIV(q[ind1],params=c(m,nu,location,scale)) *
                  scale/(2*m-1) * (1i - x[ind1]) *
-                 PearsonDS:::F21(1,m+nu/2*1i,2*m,2/(1-1i*x[ind1]),tol,...)
+                 F21(1,m+nu/2*1i,2*m,2/(1-1i*x[ind1]),tol,...)
 
     res[ind2] <- 1-dpearsonIV(-q[ind2],params=c(m,-nu,-location,scale)) *
                  scale/(2*m-1) * (1i + x[ind2]) *
-                 PearsonDS:::F21(1,m-nu/2*1i,2*m,2/(1+1i*x[ind2]),tol,...)
+                 F21(1,m-nu/2*1i,2*m,2/(1+1i*x[ind2]),tol,...)
     if (abs(nu)<(4-2*sqrt(3))*m) {
       res[ind3] <- (1-exp(-(nu+1i*2*m)*pi))^(-1) -
                    (1i*scale*dpearsonIV(q[ind3],params=c(m,nu,location,scale)))/
                    (1i*nu-2*m+2) * (1+x[ind3]^2) *
-                   PearsonDS:::F21_3_5(1,2-2*m,2-m+1i*nu/2,(1+1i*x[ind3])/2,
+                   F21_3_5(1,2-2*m,2-m+1i*nu/2,(1+1i*x[ind3])/2,
                                        tol,...)
       res[ind4] <- 1 - (1-exp(-(-nu+1i*2*m)*pi))^(-1) +
                    (1i*scale*dpearsonIV(-q[ind4],params=c(m,-nu,-location,scale)
                    ))/(1i*(-nu)-2*m+2) * (1+(-x[ind4])^2) *
-                   PearsonDS:::F21_3_5(1,2-2*m,2-m-1i*nu/2,(1-1i*x[ind4])/2,
+                   F21_3_5(1,2-2*m,2-m-1i*nu/2,(1-1i*x[ind4])/2,
                                        tol,...)
     } else {
       res[ind3] <- (1-exp(-(nu+1i*2*m)*pi))^(-1) -
                    (1i*scale*dpearsonIV(q[ind3],params=c(m,nu,location,scale)))/
                    (1i*nu-2*m+2) * (1+x[ind3]^2) *
-                   PearsonDS:::F21(1,2-2*m,2-m+1i*nu/2,(1+1i*x[ind3])/2,tol,...)
+                   F21(1,2-2*m,2-m+1i*nu/2,(1+1i*x[ind3])/2,tol,...)
       res[ind4] <- 1 - (1-exp(-(-nu+1i*2*m)*pi))^(-1) +
                    (1i*scale*dpearsonIV(-q[ind4],params=c(m,-nu,-location,scale)
                    ))/(1i*(-nu)-2*m+2) * (1+(-x[ind4])^2) *
-                   PearsonDS:::F21(1,2-2*m,2-m-1i*nu/2,(1-1i*x[ind4])/2,tol,...)
+                   F21(1,2-2*m,2-m-1i*nu/2,(1-1i*x[ind4])/2,tol,...)
     }
     res <- Re(res)
   }
@@ -201,7 +204,7 @@ function(q,m,nu,location,scale,params,DEBUG=FALSE,tol=1e-8) {
   u    <- 1-m+nu/2*1i
   norm <- exp(gsl::lngamma_complex(u+1)-gsl::lngamma_complex(u+2*m-1)+lgamma(2*m-1))
   Re((exp(-nu*phi)*exp((2-2*m)*phi*1i)*
-     (PearsonDS:::F21(2-2*m,u,u+1,exp(phi*2i),DEBUG=DEBUG,tol=tol)/
+     (F21(2-2*m,u,u+1,exp(phi*2i),DEBUG=DEBUG,tol=tol)/
      norm)-1)/
      (exp(-nu*pi)*exp((2-2*m)*pi*1i)-1))
 }
